(body-bytes obj)If obj is a byte-array, return it, otherwise use utf8-bytes.
If `obj` is a byte-array, return it, otherwise use `utf8-bytes`.
(initialize-request-hook)(matches address method request)(try-intercept origfn request)(try-intercept origfn request respond raise)(url-encode string)encodes string into valid URL string
encodes string into valid URL string
(utf8-bytes s)Returns the UTF-8 bytes corresponding to the given string.
Returns the UTF-8 bytes corresponding to the given string.
(with-fake-routes routes & body)Makes all wrapped clj-http requests first match against given routes. The actual HTTP request will be sent only if no matches are found.
Makes all wrapped clj-http requests first match against given routes. The actual HTTP request will be sent only if no matches are found.
(with-fake-routes-in-isolation routes & body)Makes all wrapped clj-http requests first match against given routes. If no route matches, an exception is thrown.
Makes all wrapped clj-http requests first match against given routes. If no route matches, an exception is thrown.
(with-global-fake-routes routes & body)(with-global-fake-routes-in-isolation routes & body)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |